==> TransProR_0.0.6.tar.gz: TransProR/README.md <==
# TransProR
[![R-CMD-check](https://github.com/SSSYDYSSS/TransProR/workflows/R-CMD-check/badge.svg)](https://github.com/SSSYDYSSS/TransProR/actions)
<!-- badges: start -->

<!-- badges: end -->

<img src="vignettes/image/TransProR_rlogo.png" alt="TransProR Logo" width="210" height="250" align="right">
Analysis and visualization of transcriptomic data are currently in progress. Future directions include multi-modal fusion, sparse learning, and the investigation of spatio-temporal effects.

## Installation

You can install the released version of TransProR from CRAN with:

``` r
install.packages("TransProR")
```

You can install the development version of TransProR like so:

``` r
install.packages("devtools")
devtools::install_github("SSSYDYSSS/TransProR", build_vignettes = TRUE)

install.packages("remotes")
remotes::install_github("SSSYDYSSS/TransProR", build_vignettes = TRUE)
```

## System Requirements

-   R (>= 4.3.0)

## Example

This is a basic example which shows you how to solve a common problem:

``` r
library(TransProR)
## basic example code
```
## Citation

Yu Dongyue (2023). TransProR: Analysis and visualization of transcriptomic data are currently in progress. Future directions include multi-modal fusion, sparse learning, and the investigation of spatio-temporal effects.
<https://github.com/SSSYDYSSS/TransProR>, 
<https://sssydysss.github.io/TransProRBook/>.


## Code of Conduct

Please note that the TransProR project is released with a [Contributor Code of Conduct](https://contributor-covenant.org/version/2/1/CODE_OF_CONDUCT.html). By contributing to this project, you agree to abide by its terms. "\# TransProR"

==> TransProR_1.0.3.tar.gz: TransProR/README.md <==
# TransProR
[![R-CMD-check](https://github.com/SSSYDYSSS/TransProR/workflows/R-CMD-check/badge.svg)](https://github.com/SSSYDYSSS/TransProR/actions) 

<!-- badges: start -->

<!-- badges: end -->

<img src="vignettes/image/TransProR_rlogo.png" alt="TransProR Logo" width="210" height="250" align="right">
Analysis and visualization of transcriptomic data are currently in progress. Future directions include multi-modal fusion, sparse learning, and the investigation of spatio-temporal effects.

## Installation

You can install the development version of TransProR like so:

``` r
install.packages("devtools")
devtools::install_github("SSSYDYSSS/TransProR", build_vignettes = TRUE)

install.packages("remotes")
remotes::install_github("SSSYDYSSS/TransProR", build_vignettes = TRUE)
```
## More examples see

TransProR Manual：https://sssydysss.github.io/TransProRBook/

## System Requirements

-   R (>= 4.3.0)

## Example

This is a basic example which shows you how to solve a common problem:

``` r
library(TransProR)
## basic example code
```
## Citation

Yu Dongyue (2023). TransProR: Analysis and visualization of transcriptomic data are currently in progress. Future directions include multi-modal fusion, sparse learning, and the investigation of spatio-temporal effects.
<https://github.com/SSSYDYSSS/TransProR>, 
<https://sssydysss.github.io/TransProRBook/>.


## Code of Conduct

Please note that the TransProR project is released with a [Contributor Code of Conduct](https://contributor-covenant.org/version/2/1/CODE_OF_CONDUCT.html). By contributing to this project, you agree to abide by its terms. "\# TransProR"
